<?xml version="1.0" ?><!DOCTYPE TS><TS language="he" version="2.1">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>העתקת הצבע %1 ללוח הגזירים</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="50"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="72"/>
        <source>Deepin Picker</source>
        <translation>הבוחר של Deepin</translation>
    </message>
</context>
</TS>